@@ -1,7 +1,7 @@
 
-__version__ = '0.9.5'
-__author__ = 'Zixuan Rao'
-__email__ = 'billrao@me.com'
+__version__ = '0.9.7.1'
+__author__ = 'Bruno Rocha, Zixuan Rao, Flasgger team'
+__email__ = 'flasgger@flasgger.org'
 
 # Based on works of Bruno Rocha and the Flasgger open source community
 
